@@ -15,9 +15,11 @@
  */
 
 #include <gconf/gconf-client.h>
+#include <profiles/audio-profile-choose.h>
 #include <string.h>
 #include "config.h"
 #include "prefs.h"
+#include "trayicon.h"
 #include "gui.h"
 #include "rec_tech.h"
 
@@ -47,18 +49,21 @@ gboolean save_settings(void)
 	gconf_client_set_string(client, "/apps/gnomeradio/mixer", settings.mixer, NULL);
 	gconf_client_set_string(client, "/apps/gnomeradio/mixer-device", settings.mixer_dev, NULL);
 	gconf_client_set_bool(client, "/apps/gnomeradio/mute-on-exit", settings.mute_on_exit, NULL);
-	//gconf_client_set_float(client, "/apps/gnomeradio/volume", volume->value, NULL);
+	/*gconf_client_set_float(client, "/apps/gnomeradio/volume", volume->value, NULL);*/
 	gconf_client_set_float(client, "/apps/gnomeradio/last-freq", adj->value/STEPS, NULL);
 
 	/* Store recording settings */
-	gconf_client_set_string(client, "/apps/gnomeradio/recording/audiodevice", rec_settings.audiodevice, NULL);
-	gconf_client_set_string(client, "/apps/gnomeradio/recording/destination", rec_settings.destination, NULL);
+/*	gconf_client_set_string(client, "/apps/gnomeradio/recording/audiodevice", rec_settings.audiodevice, NULL);
 	gconf_client_set_bool(client, "/apps/gnomeradio/recording/record-as-mp3", rec_settings.mp3, NULL);
 	gconf_client_set_string(client, "/apps/gnomeradio/recording/sample-rate", rec_settings.rate, NULL);
 	gconf_client_set_string(client, "/apps/gnomeradio/recording/sample-format", rec_settings.sample, NULL);
 	gconf_client_set_bool(client, "/apps/gnomeradio/recording/record-in-stereo", rec_settings.stereo, NULL);
 	gconf_client_set_string(client, "/apps/gnomeradio/recording/encoder", rec_settings.encoder, NULL);
 	gconf_client_set_string(client, "/apps/gnomeradio/recording/bitrate", rec_settings.bitrate, NULL);
+*/
+
+	gconf_client_set_string(client, "/apps/gnomeradio/recording/destination", rec_settings.destination, NULL);
+	gconf_client_set_string(client, "/apps/gnomeradio/recording/profile", rec_settings.profile, NULL);
 
 	/* Store the presets */
 	count = g_list_length(settings.presets);
@@ -74,7 +79,7 @@ gboolean save_settings(void)
 		g_free(buffer);
 	}	
 	gconf_client_set_int(client, "/apps/gnomeradio/presets/last", mom_ps, NULL);
-	g_print("Storing Settings in GConf database\n");
+	/*g_print("Storing Settings in GConf database\n");*/
 	
 	return TRUE;
 }			
@@ -107,7 +112,7 @@ gboolean load_settings(void)
 	if (!settings.mixer_dev)
 		settings.mixer_dev = g_strdup("/dev/mixer");
 	settings.mute_on_exit = gconf_client_get_bool(client, "/apps/gnomeradio/mute-on-exit", NULL);
-	//volume->value = gconf_client_get_float(client, "/apps/gnomeradio/volume", NULL);
+	/*volume->value = gconf_client_get_float(client, "/apps/gnomeradio/volume", NULL);*/
 	freq = gconf_client_get_float(client, "/apps/gnomeradio/last-freq", NULL);
 	if ((freq < FREQ_MIN) || (freq > FREQ_MAX))
 		adj->value = FREQ_MIN * STEPS;
@@ -115,12 +120,9 @@ gboolean load_settings(void)
 		adj->value = freq * STEPS;
 	
 	/* Load recording settings */
-	rec_settings.audiodevice = gconf_client_get_string(client, "/apps/gnomeradio/recording/audiodevice", NULL);
+/*	rec_settings.audiodevice = gconf_client_get_string(client, "/apps/gnomeradio/recording/audiodevice", NULL);
 	if (!rec_settings.audiodevice)
 		rec_settings.audiodevice = g_strdup("/dev/audio");
-	rec_settings.destination = gconf_client_get_string(client, "/apps/gnomeradio/recording/destination", NULL);
-	if (!rec_settings.destination)
-		rec_settings.destination = g_strdup(g_get_home_dir());
 	rec_settings.mp3 = gconf_client_get_bool(client, "/apps/gnomeradio/recording/record-as-mp3", NULL);
 	rec_settings.rate = gconf_client_get_string(client, "/apps/gnomeradio/recording/sample-rate", NULL);
 	if (!rec_settings.rate)
@@ -134,20 +136,25 @@ gboolean load_settings(void)
 		rec_settings.encoder = g_strdup("oggenc");
 	rec_settings.bitrate = gconf_client_get_string(client, "/apps/gnomeradio/recording/bitrate", NULL);
 	if (!rec_settings.bitrate)
-		rec_settings.bitrate = g_strdup("192");
+		rec_settings.bitrate = g_strdup("192");*/
+
+	rec_settings.destination = gconf_client_get_string(client, "/apps/gnomeradio/recording/destination", NULL);
+	if (!rec_settings.destination)
+		rec_settings.destination = g_strdup(g_get_home_dir());
+	rec_settings.profile = gconf_client_get_string(client, "/apps/gnomeradio/recording/profile", NULL);
+	if (!rec_settings.profile)
+		rec_settings.profile = g_strdup("cdlossy");
 	
 	/* Load the presets */
 	count = gconf_client_get_int(client, "/apps/gnomeradio/presets/presets", NULL);
 	for (i=0;i<count;i++)
 	{
-		char *tmp;
 		ps = malloc(sizeof(preset));
 		buffer = g_strdup_printf("/apps/gnomeradio/presets/%d/name", i);
-		tmp = gconf_client_get_string(client, buffer, NULL); 
-		if (!tmp)
-			tmp = "unnamed";
-		ps->title = g_strdup(tmp);
+		ps->title = gconf_client_get_string(client, buffer, NULL); 
 		g_free(buffer);
+		if (!ps->title)
+			ps->title = g_strdup(_("unnamed"));
 		buffer = g_strdup_printf("/apps/gnomeradio/presets/%d/freqency", i);
 		freq = gconf_client_get_float(client, buffer, NULL); 
 		if ((freq < FREQ_MIN) || (freq > FREQ_MAX))
@@ -178,7 +185,7 @@ static gboolean device_entry_activate_cb(GtkWidget *widget, gpointer data)
 	if (settings.device) g_free(settings.device);
 	settings.device = g_strdup(text);
 	
-	start_radio(TRUE);
+	start_radio(TRUE, data);
 	
 	return FALSE;
 }
@@ -206,12 +213,12 @@ static gboolean mixer_combo_change_cb(GtkComboBox *combo, gpointer data)
 	if ((tmp = strstr(settings.mixer, " (")))
 		tmp[0] = '\0';
 	
-	start_mixer(TRUE);
+	start_mixer(TRUE, data);
 	
 	return FALSE;
 }
 
-static gboolean bitrate_combo_change_cb(GtkComboBox *combo, gpointer data)
+/*static gboolean bitrate_combo_change_cb(GtkComboBox *combo, gpointer data)
 {
 	GList *bitrates;
 	gint active;
@@ -229,9 +236,9 @@ static gboolean bitrate_combo_change_cb(GtkComboBox *combo, gpointer data)
 	rec_settings.bitrate = g_strdup(bitrate);
 	
 	return FALSE;
-}
+}*/
 
-static gboolean encoder_combo_change_cb(GtkComboBox *combo, gpointer bitrate_combo)
+/*static gboolean encoder_combo_change_cb(GtkComboBox *combo, gpointer bitrate_combo)
 {
 	GList *encoders;
 	gint active;
@@ -253,6 +260,17 @@ static gboolean encoder_combo_change_cb(GtkComboBox *combo, gpointer bitrate_com
 	}
 	gtk_widget_set_sensitive(bitrate_combo, rec_settings.mp3);
 	
+	return FALSE;
+}*/
+
+static gboolean profile_combo_change_cb(GtkComboBox *combo, gpointer userdata)
+{
+	GMAudioProfile* profile = gm_audio_profile_choose_get_active(GTK_WIDGET(combo));
+
+	g_assert(rec_settings.profile);
+	g_free(rec_settings.profile);
+	rec_settings.profile = g_strdup(gm_audio_profile_get_id(profile));
+
 	return FALSE;
 }
 
@@ -263,9 +281,11 @@ static void add_button_clicked_cb(GtkWidget *widget, gpointer data)
 	GtkTreeIter iter = {0};
 	GtkAdjustment* v_scb;
 	GtkTreePath *path = NULL;
+	GList* menuitems;
+	GtkWidget *menuitem;
 	
 	ps = malloc(sizeof(preset));
-	ps->title = g_strdup(_("unamed"));
+	ps->title = g_strdup(_("unnamed"));
 	ps->freq = rint(adj->value) / STEPS;
 	settings.presets = g_list_append(settings.presets, (gpointer) ps);
 	buffer = g_strdup_printf("%.2f", ps->freq);
@@ -282,7 +302,14 @@ static void add_button_clicked_cb(GtkWidget *widget, gpointer data)
 	gtk_combo_box_append_text(GTK_COMBO_BOX(preset_combo), ps->title);
 	mom_ps = g_list_length(settings.presets) - 1;
 	preset_combo_set_item(mom_ps);
-	
+
+	menuitems = GTK_MENU_SHELL(tray_menu)->children;
+	menuitem = gtk_menu_item_new_with_label(ps->title); 
+		
+	gtk_menu_shell_insert(GTK_MENU_SHELL(tray_menu), menuitem, mom_ps);		
+	g_signal_connect(G_OBJECT(menuitem), "activate", (GCallback)preset_menuitem_activate_cb, (gpointer)mom_ps);
+	gtk_widget_show(menuitem);
+
 	buffer = g_strdup_printf("%d", g_list_length(settings.presets) - 1);
 	path = gtk_tree_path_new_from_string(buffer);
 	g_free(buffer);
@@ -298,6 +325,8 @@ static void del_button_clicked_cb(GtkWidget *widget, gpointer data)
 	GtkTreeIter iter;
 	preset *ps;
 	int *row;
+	GList* menuitems;
+	GtkWidget *menuitem;
 	
 	gtk_tree_view_get_cursor(GTK_TREE_VIEW(list_view), &path, &focus_column);
 	
@@ -320,6 +349,11 @@ static void del_button_clicked_cb(GtkWidget *widget, gpointer data)
 	if (--mom_ps < 0) mom_ps = 0;
 	if (!g_list_length(settings.presets)) mom_ps = -1;
 	preset_combo_set_item(mom_ps);
+
+	menuitems = GTK_MENU_SHELL(tray_menu)->children;
+	g_assert(*row < g_list_length(menuitems));
+	menuitem = g_list_nth_data(menuitems, *row);
+	gtk_widget_destroy(menuitem);
 	
 	gtk_tree_path_prev(path);
 	gtk_tree_view_set_cursor(GTK_TREE_VIEW(list_view), path, NULL, FALSE);
@@ -361,6 +395,8 @@ static void name_cell_edited_cb(GtkCellRendererText *cellrenderertext, gchar *pa
 	GtkTreeIter iter;
 	preset *ps;
 	int *row;
+	GList* menuitems;
+	GtkWidget *menuitem;
 	
 	path = gtk_tree_path_new_from_string(path_str);
 
@@ -377,6 +413,16 @@ static void name_cell_edited_cb(GtkCellRendererText *cellrenderertext, gchar *pa
 	gtk_combo_box_insert_text(GTK_COMBO_BOX(preset_combo), *row + 1, ps->title);
 	preset_combo_set_item(mom_ps);
 	
+	menuitems = GTK_MENU_SHELL(tray_menu)->children;
+	g_assert(mom_ps < g_list_length(menuitems));
+	menuitem = g_list_nth_data(menuitems, mom_ps);
+	gtk_widget_destroy(menuitem);
+	menuitem = gtk_menu_item_new_with_label(ps->title); 
+		
+	gtk_menu_shell_insert(GTK_MENU_SHELL(tray_menu), menuitem, *row);		
+	g_signal_connect(G_OBJECT(menuitem), "activate", (GCallback)preset_menuitem_activate_cb, (gpointer)mom_ps);
+	gtk_widget_show(menuitem);
+	
 	gtk_tree_model_get_iter(GTK_TREE_MODEL(list_store), &iter, path);
 	gtk_list_store_set(GTK_LIST_STORE(list_store), &iter, 0, new_val, -1);
 	gtk_tree_path_free(path);	
@@ -445,17 +491,17 @@ static void free_string_list(GList *list)
 	g_list_free(list);
 }
 
-GtkWidget* prefs_window(void)
+GtkWidget* prefs_window(GtkWidget *app)
 {
 	GtkWidget *dialog;
 	GtkWidget *box, *sbox, *pbox, *rbox;
 	GtkWidget *settings_box, *presets_box, *record_box;
 	GtkWidget *settings_label, *presets_label, *record_label;
 	GtkWidget *s_indent_label, *p_indent_label, *r_indent_label;
-	GtkWidget *encoder_label, *bitrate_label, *destination_label;
+	GtkWidget *destination_label;
 	GtkWidget *destination_button;
-	GtkWidget *encoder_combo, *bitrate_combo;
-	GtkWidget *mixer_eb, *encoder_eb, *bitrate_eb;
+	GtkWidget *profile_combo;
+	GtkWidget *mixer_eb, *profile_eb;
 	GtkWidget *preset_box;
 	GtkWidget *settings_table, *record_table;
 	GtkWidget *device_label, *mixer_label;
@@ -464,12 +510,12 @@ GtkWidget* prefs_window(void)
 	GtkWidget *scrolled_window;
 	GtkCellRenderer *cellrenderer;
 	GtkTreeViewColumn *list_column;
-	GList *mixer_devs, *encoders, *bitrates, *ptr;
+	GList *mixer_devs, *profiles, *ptr;
 	gint i, active;
 	char *settings_hdr, *presets_hdr, *record_hdr;
 	preset* ps;
 	
-	dialog = gtk_dialog_new_with_buttons(_("Gnomeradio Settings"), NULL, 
+	dialog = gtk_dialog_new_with_buttons(_("Gnomeradio Settings"), GTK_WINDOW(app), 
 			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR,
 			GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, 
 			GTK_STOCK_HELP, GTK_RESPONSE_HELP,
@@ -552,9 +598,9 @@ GtkWidget* prefs_window(void)
 
 	gtk_table_attach_defaults(GTK_TABLE(settings_table), mute_on_exit_cb, 0, 2, 2, 3);
 
-	g_signal_connect(GTK_OBJECT(device_entry), "hide", GTK_SIGNAL_FUNC(device_entry_activate_cb), NULL);
+	g_signal_connect(GTK_OBJECT(device_entry), "hide", GTK_SIGNAL_FUNC(device_entry_activate_cb), app);
 	g_signal_connect(GTK_OBJECT(device_entry), "activate", GTK_SIGNAL_FUNC(device_entry_activate_cb), NULL);
-	g_signal_connect(GTK_OBJECT(mixer_combo), "changed", GTK_SIGNAL_FUNC(mixer_combo_change_cb), NULL);
+	g_signal_connect(GTK_OBJECT(mixer_combo), "changed", GTK_SIGNAL_FUNC(mixer_combo_change_cb), app);
 	g_signal_connect(GTK_OBJECT(mute_on_exit_cb), "toggled", GTK_SIGNAL_FUNC(mute_on_exit_toggled_cb), NULL);
 
 	gtk_tooltips_set_tip(tooltips, device_entry, _("Specify the radio-device (in most cases /dev/radio)"), NULL);
@@ -569,7 +615,7 @@ GtkWidget* prefs_window(void)
 	p_indent_label = gtk_label_new("    ");
 	gtk_box_pack_start(GTK_BOX(pbox), p_indent_label, FALSE, FALSE, 0);
 
-	preset_box = gtk_hbox_new(FALSE, 10);
+	preset_box = gtk_vbox_new(FALSE, 10);
 	gtk_box_pack_start(GTK_BOX(pbox), preset_box, TRUE, TRUE, 0);
 
 	scrolled_window = gtk_scrolled_window_new(NULL, NULL);
@@ -577,8 +623,8 @@ GtkWidget* prefs_window(void)
 	list_view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(list_store));
 	gtk_container_add(GTK_CONTAINER(scrolled_window), list_view);
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled_window), GTK_SHADOW_IN);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-	gtk_widget_set_size_request(list_view, 200, 100);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	gtk_widget_set_size_request(list_view, 200, 150);
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(list_view), FALSE);
 	
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(list_view));
@@ -590,8 +636,7 @@ GtkWidget* prefs_window(void)
 	cellrenderer->mode = GTK_CELL_RENDERER_MODE_EDITABLE;
 	GTK_CELL_RENDERER_TEXT(cellrenderer)->editable = TRUE;
 	list_column = gtk_tree_view_column_new_with_attributes(NULL, cellrenderer, "text", 0, NULL);
-	gtk_tree_view_column_set_min_width(list_column, 130);
-	gtk_tree_view_column_set_max_width(list_column, 130);
+	gtk_tree_view_column_set_min_width(list_column, 150);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(list_view), list_column);
 	g_signal_connect(GTK_OBJECT(cellrenderer), "edited", GTK_SIGNAL_FUNC(name_cell_edited_cb), NULL);
 
@@ -603,13 +648,13 @@ GtkWidget* prefs_window(void)
 	gtk_tree_view_append_column(GTK_TREE_VIEW(list_view), list_column);
 	g_signal_connect(GTK_OBJECT(cellrenderer), "edited", GTK_SIGNAL_FUNC(freq_cell_edited_cb), NULL);
 
-	button_box = gtk_vbox_new(FALSE, 15);
+	button_box = gtk_hbox_new(FALSE, 12);
 
 	add_button = gtk_button_new_from_stock(GTK_STOCK_ADD);
 	del_button = gtk_button_new_from_stock(GTK_STOCK_DELETE);
 	
-	gtk_box_pack_start(GTK_BOX(button_box), add_button, FALSE, FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(button_box), del_button, FALSE, FALSE, 0);
+	gtk_box_pack_end(GTK_BOX(button_box), del_button, FALSE, FALSE, 0);
+	gtk_box_pack_end(GTK_BOX(button_box), add_button, FALSE, FALSE, 0);
 	
 	gtk_box_pack_start(GTK_BOX(preset_box), scrolled_window, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(preset_box), button_box, TRUE, TRUE, 0);
@@ -639,80 +684,29 @@ GtkWidget* prefs_window(void)
 	r_indent_label = gtk_label_new("    ");
 	gtk_box_pack_start(GTK_BOX(rbox), r_indent_label, FALSE, FALSE, 0);
 
-	bitrates = g_list_append(NULL, g_strdup("32"));
-	bitrates = g_list_append(bitrates, g_strdup("40"));
-	bitrates = g_list_append(bitrates, g_strdup("48"));
-	bitrates = g_list_append(bitrates, g_strdup("56"));
-	bitrates = g_list_append(bitrates, g_strdup("64"));
-	bitrates = g_list_append(bitrates, g_strdup("80"));
-	bitrates = g_list_append(bitrates, g_strdup("96"));
-	bitrates = g_list_append(bitrates, g_strdup("112"));
-	bitrates = g_list_append(bitrates, g_strdup("128"));
-	bitrates = g_list_append(bitrates, g_strdup("160"));
-	bitrates = g_list_append(bitrates, g_strdup("192"));
-	bitrates = g_list_append(bitrates, g_strdup("224"));
-	bitrates = g_list_append(bitrates, g_strdup("256"));
-	bitrates = g_list_append(bitrates, g_strdup("320"));
-
-	record_table = gtk_table_new(3, 2, FALSE);
+	record_table = gtk_table_new(2, 2, FALSE);
 	gtk_table_set_col_spacings(GTK_TABLE(record_table), 15);
 	gtk_table_set_row_spacings(GTK_TABLE(record_table), 5);
 	
-	encoder_label = gtk_label_new(_("Encoder:"));
-	bitrate_label = gtk_label_new(_("Bitrate:"));
 	destination_label = gtk_label_new(_("Destination directory:"));
-	gtk_misc_set_alignment(GTK_MISC(encoder_label), 0.0f, 0.5f); 
-	gtk_misc_set_alignment(GTK_MISC(bitrate_label), 0.0f, 0.5f);
 	gtk_misc_set_alignment(GTK_MISC(destination_label), 0.0f, 0.5f);
 
 	destination_button = gtk_button_new();
 	gtk_button_set_label(GTK_BUTTON(destination_button), rec_settings.destination);
 	
-	encoder_eb = gtk_event_box_new();
-	encoder_combo = gtk_combo_box_new_text();
-	gtk_container_add(GTK_CONTAINER(encoder_eb), encoder_combo);
-	encoders = get_installed_encoders();
-	if (!encoders) rec_settings.mp3 = FALSE;
-	ptr = encoders = g_list_prepend(encoders, (gpointer)g_strdup(_("Wave file")));
-	for (i = 0, active = 0; ptr; ptr = g_list_next(ptr)) {
-		gtk_combo_box_append_text(GTK_COMBO_BOX(encoder_combo), ptr->data);
-		if (g_str_equal(ptr->data, rec_settings.encoder)) active = i;
-		++i;
-	}
-	
-	if (!rec_settings.mp3) active = 0;
-	gtk_combo_box_set_active(GTK_COMBO_BOX(encoder_combo), active);
-	if (encoders) g_object_set_data_full(G_OBJECT(encoder_combo), "encoders", encoders, (GDestroyNotify)free_string_list);
-	
-	bitrate_eb = gtk_event_box_new();
-	bitrate_combo = gtk_combo_box_new_text();
-	gtk_container_add(GTK_CONTAINER(bitrate_eb), bitrate_combo);
-	ptr = bitrates;
-	for (i = 0, active = 0; ptr; ptr = g_list_next(ptr)) {
-		gchar *buffer = g_strdup_printf(_("%s kb/s"), (gchar*)ptr->data);
-		gtk_combo_box_append_text(GTK_COMBO_BOX(bitrate_combo), buffer);
-		g_free(buffer);
-		if (!strncmp(ptr->data, rec_settings.bitrate, strlen(rec_settings.bitrate))) active = i;
-		++i;
-	}
-	gtk_combo_box_set_active(GTK_COMBO_BOX(bitrate_combo), active);
-	g_object_set_data_full(G_OBJECT(bitrate_combo), "bitrates", bitrates, (GDestroyNotify)free_string_list);
-
-	gtk_widget_set_sensitive(bitrate_combo, rec_settings.mp3);
+	profile_eb = gtk_event_box_new();
+	profile_combo = gm_audio_profile_choose_new();
+	gtk_container_add(GTK_CONTAINER(profile_eb), profile_combo);
+	gm_audio_profile_choose_set_active(profile_combo, rec_settings.profile);
 
 	gtk_table_attach_defaults(GTK_TABLE(record_table), destination_label, 0, 1, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(record_table), destination_button, 1, 2, 0, 1);
-	gtk_table_attach_defaults(GTK_TABLE(record_table), encoder_label, 0, 1, 1, 2);
-	gtk_table_attach_defaults(GTK_TABLE(record_table), encoder_eb, 1, 2, 1, 2);
-	gtk_table_attach_defaults(GTK_TABLE(record_table), bitrate_label, 0, 1, 2, 3);
-	gtk_table_attach_defaults(GTK_TABLE(record_table), bitrate_eb, 1, 2, 2, 3);
+	gtk_table_attach_defaults(GTK_TABLE(record_table), profile_eb, 0, 2, 1, 2);
 
 	g_signal_connect(GTK_OBJECT(destination_button), "clicked", GTK_SIGNAL_FUNC(destination_button_clicked_cb), NULL);
-	g_signal_connect(GTK_OBJECT(encoder_combo), "changed", GTK_SIGNAL_FUNC(encoder_combo_change_cb), (gpointer)bitrate_combo);
-	g_signal_connect(GTK_OBJECT(bitrate_combo), "changed", GTK_SIGNAL_FUNC(bitrate_combo_change_cb), NULL);
+	g_signal_connect(GTK_OBJECT(profile_combo), "changed", GTK_SIGNAL_FUNC(profile_combo_change_cb), NULL);
 
-	gtk_tooltips_set_tip(tooltips, encoder_eb, _("Choose the mp3-/ogg-encoder that should be used, or to record as a uncompressed wave file"), NULL);
-	gtk_tooltips_set_tip(tooltips, bitrate_eb, _("Choose the bitrate in which the mp3/ogg will be encoded"), NULL);
+	gtk_tooltips_set_tip(tooltips, profile_eb, _("Choose the Media Profile that should be used to record."), NULL);
 	
 	gtk_box_pack_start(GTK_BOX(rbox), record_table, TRUE, TRUE, 0);
 
