@@ -17,17 +17,6 @@
 #ifndef _TECH_H
 #define _TECH_H
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <string.h>
-#include <fcntl.h>
-#include <sys/ioctl.h>
-#include <assert.h>
-
-#include <linux/videodev.h>
-#include <sys/soundcard.h>
-
 int mixer_init(char *mixer_device, char *mixer_source);
 
 char* mixer_get_sndcard_name(void);
@@ -44,10 +33,14 @@ int mixer_set_rec_device(void);
 
 int radio_init(char *device);
 
+int radio_is_init(void);
+
 void radio_stop(void);
 
 int radio_setfreq(float freq);
 
+int radio_check_station(float freq);
+
 void radio_unmute();
 
 void radio_mute();
